componenttools.Component
========================

.. abjad-lineage:: abjad.tools.componenttools.Component.Component.Component

.. autoclass:: abjad.tools.componenttools.Component.Component.Component
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.componenttools.Component.Component.Component.descendants
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Component.Component.Component.duration_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Component.Component.Component.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Component.Component.Component.lineage
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Component.Component.Component.override
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Component.Component.Component.parent
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Component.Component.Component.parentage
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Component.Component.Component.prolated_duration
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Component.Component.Component.prolation
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Component.Component.Component.set
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Component.Component.Component.spanners
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Component.Component.Component.start_offset
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Component.Component.Component.start_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Component.Component.Component.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Component.Component.Component.stop_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Component.Component.Component.storage_format
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Component.Component.Component.timespan
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Component.Component.Component.timespan_in_seconds
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.componenttools.Component.Component.Component.__eq__
   :noindex:

.. automethod:: abjad.tools.componenttools.Component.Component.Component.__ge__
   :noindex:

.. automethod:: abjad.tools.componenttools.Component.Component.Component.__gt__
   :noindex:

.. automethod:: abjad.tools.componenttools.Component.Component.Component.__le__
   :noindex:

.. automethod:: abjad.tools.componenttools.Component.Component.Component.__lt__
   :noindex:

.. automethod:: abjad.tools.componenttools.Component.Component.Component.__mul__
   :noindex:

.. automethod:: abjad.tools.componenttools.Component.Component.Component.__ne__
   :noindex:

.. automethod:: abjad.tools.componenttools.Component.Component.Component.__repr__
   :noindex:

.. automethod:: abjad.tools.componenttools.Component.Component.Component.__rmul__
   :noindex:
